<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Thu Jun 18 2020 23:48:23 GMT+0000 (Coordinated Universal Time)


## Refactor
  - Refactored health checks for SR API, SR Auth, and TheTVDB
  ([ba4dee5d](https://gitlab-ci-token:kzfU5fYdz8meE9pFwb_-@git.sickrage.ca/SiCKRAGE/sickrage/commit/ba4dee5d002a4b6c3b7b5253490750e939c1d4b4))
  - Refactored app_id to server_id Refactored SR API calls related to app_id to relate to new server_id Refactored SR API to v4
  ([a928edb0](https://gitlab-ci-token:kzfU5fYdz8meE9pFwb_-@git.sickrage.ca/SiCKRAGE/sickrage/commit/a928edb06b436ca9495f75ae65a467aeb10f3624))




